import { ReactNode } from "react";
import { TranslationKey } from "../languageHandler";
import { SettingLevel } from "./SettingLevel";
import SettingController from "./controllers/SettingController";
import { WatchManager } from "./WatchManager";
export declare const defaultWatchManager: WatchManager;
export declare enum LabGroup {
    Messaging = 0,
    Profile = 1,
    Spaces = 2,
    Widgets = 3,
    Rooms = 4,
    VoiceAndVideo = 5,
    Moderation = 6,
    Analytics = 7,
    Themes = 8,
    Encryption = 9,
    Experimental = 10,
    Developer = 11
}
export declare enum Features {
    VoiceBroadcast = "feature_voice_broadcast",
    VoiceBroadcastForceSmallChunks = "feature_voice_broadcast_force_small_chunks",
    NotificationSettings2 = "feature_notification_settings2",
    OidcNativeFlow = "feature_oidc_native_flow"
}
export declare const labGroupNames: Record<LabGroup, TranslationKey>;
export type SettingValueType = boolean | number | string | number[] | string[] | Record<string, unknown> | Record<string, unknown>[] | null;
export interface IBaseSetting<T extends SettingValueType = SettingValueType> {
    isFeature?: false | undefined;
    displayName?: TranslationKey | Partial<{
        [level in SettingLevel]: TranslationKey;
    }>;
    description?: TranslationKey | (() => ReactNode);
    supportedLevels: SettingLevel[];
    default: T;
    controller?: SettingController;
    supportedLevelsAreOrdered?: boolean;
    invertedSettingName?: string;
    betaInfo?: {
        title: TranslationKey;
        caption: () => ReactNode;
        faq?: (enabled: boolean) => ReactNode;
        image?: string;
        feedbackSubheading?: TranslationKey;
        feedbackLabel?: string;
        extraSettings?: string[];
        requiresRefresh?: boolean;
    };
    shouldWarn?: boolean;
}
export interface IFeature extends Omit<IBaseSetting<boolean>, "isFeature"> {
    isFeature: true;
    labsGroup: LabGroup;
}
export type ISetting = IBaseSetting | IFeature;
export declare const SETTINGS: {
    [setting: string]: ISetting;
};
