import { MatrixClient } from "matrix-js-sdk/src/matrix";
/**
 * @experimental
 * Stores information about configured OIDC provider
 */
export declare class OidcClientStore {
    private readonly matrixClient;
    private oidcClient?;
    private initialisingOidcClientPromise;
    private authenticatedIssuer?;
    private _accountManagementEndpoint?;
    constructor(matrixClient: MatrixClient);
    /**
     * True when the active user is authenticated via OIDC
     */
    get isUserAuthenticatedWithOidc(): boolean;
    get accountManagementEndpoint(): string | undefined;
    /**
     * Revokes provided access and refresh tokens with the configured OIDC provider
     * @param accessToken
     * @param refreshToken
     * @returns Promise that resolves when tokens have been revoked
     * @throws when OidcClient cannot be initialised, or revoking either token fails
     */
    revokeTokens(accessToken?: string, refreshToken?: string): Promise<void>;
    /**
     * Try to revoke a given token
     * @param oidcClient
     * @param token
     * @param tokenType passed to revocation endpoint as token type hint
     * @returns Promise that resolved with boolean whether the token revocation succeeded or not
     */
    private tryRevokeToken;
    private getOidcClient;
    /**
     * Tries to initialise an OidcClient using stored clientId and OIDC discovery.
     * Assigns this.oidcClient and accountManagement endpoint.
     * Logs errors and does not throw when oidc client cannot be initialised.
     * @returns promise that resolves when initialising OidcClient succeeds or fails
     */
    private initOidcClient;
}
