import { IAnnotatedPushRule, IPushRule, IPushRules, PushRuleKind, RuleId } from "matrix-js-sdk/src/matrix";
/**
 * Default set of push rules for a new account
 * Use to mock push rule fetching, or use `getDefaultRuleWithKind`
 * to use default examples of specific push rules
 */
export declare const DEFAULT_PUSH_RULES: IPushRules;
/**
 * Get rule by id from default rules
 * @param ruleId
 * @returns {IPushRule} matching push rule
 * @returns {PushRuleKind}
 * @throws when no rule is found with ruleId
 */
export declare const getDefaultRuleWithKind: (ruleId: RuleId | string) => {
    rule: IPushRule;
    kind: PushRuleKind;
};
/**
 * Get rule by id from default rules as an IAnnotatedPushRule
 * @param ruleId
 * @returns
 */
export declare const getDefaultAnnotatedRule: (ruleId: RuleId | string) => IAnnotatedPushRule;
/**
 * Make a push rule with default values
 * @param ruleId
 * @param ruleOverrides
 * @returns IPushRule
 */
export declare const makePushRule: (ruleId: RuleId | string, ruleOverrides?: Partial<IPushRule>) => IPushRule;
export declare const makeAnnotatedPushRule: (kind: PushRuleKind, ruleId: RuleId | string, ruleOverrides?: Partial<IPushRule>) => IAnnotatedPushRule;
